function noop() { }
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function is_empty(obj) {
    return Object.keys(obj).length === 0;
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if ($$scope.dirty === undefined) {
            return lets;
        }
        if (typeof lets === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}
function update_slot(slot, slot_definition, ctx, $$scope, dirty, get_slot_changes_fn, get_slot_context_fn) {
    const slot_changes = get_slot_changes(slot_definition, $$scope, dirty, get_slot_changes_fn);
    if (slot_changes) {
        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
        slot.p(slot_context, slot_changes);
    }
}
function exclude_internal_props(props) {
    const result = {};
    for (const k in props)
        if (k[0] !== '$')
            result[k] = props[k];
    return result;
}
function compute_rest_props(props, keys) {
    const rest = {};
    keys = new Set(keys);
    for (const k in props)
        if (!keys.has(k) && k[0] !== '$')
            rest[k] = props[k];
    return rest;
}
function action_destroyer(action_result) {
    return action_result && is_function(action_result.destroy) ? action_result.destroy : noop;
}

function append(target, node) {
    target.appendChild(node);
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function element(name) {
    return document.createElement(name);
}
function listen(node, event, handler, options) {
    node.addEventListener(event, handler, options);
    return () => node.removeEventListener(event, handler, options);
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function set_attributes(node, attributes) {
    // @ts-ignore
    const descriptors = Object.getOwnPropertyDescriptors(node.__proto__);
    for (const key in attributes) {
        if (attributes[key] == null) {
            node.removeAttribute(key);
        }
        else if (key === 'style') {
            node.style.cssText = attributes[key];
        }
        else if (key === '__value') {
            node.value = node[key] = attributes[key];
        }
        else if (descriptors[key] && descriptors[key].set) {
            node[key] = attributes[key];
        }
        else {
            attr(node, key, attributes[key]);
        }
    }
}
function children(element) {
    return Array.from(element.childNodes);
}
function toggle_class(element, name, toggle) {
    element.classList[toggle ? 'add' : 'remove'](name);
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
// TODO figure out if we still want to support
// shorthand events, or if we want to implement
// a real bubbling mechanism
function bubble(component, event) {
    const callbacks = component.$$.callbacks[event.type];
    if (callbacks) {
        callbacks.slice().forEach(fn => fn(event));
    }
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
let flushing = false;
const seen_callbacks = new Set();
function flush() {
    if (flushing)
        return;
    flushing = true;
    do {
        // first, call beforeUpdate functions
        // and update components
        for (let i = 0; i < dirty_components.length; i += 1) {
            const component = dirty_components[i];
            set_current_component(component);
            update(component.$$);
        }
        set_current_component(null);
        dirty_components.length = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    flushing = false;
    seen_callbacks.clear();
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
const outroing = new Set();
let outros;
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}

function get_spread_update(levels, updates) {
    const update = {};
    const to_null_out = {};
    const accounted_for = { $$scope: 1 };
    let i = levels.length;
    while (i--) {
        const o = levels[i];
        const n = updates[i];
        if (n) {
            for (const key in o) {
                if (!(key in n))
                    to_null_out[key] = 1;
            }
            for (const key in n) {
                if (!accounted_for[key]) {
                    update[key] = n[key];
                    accounted_for[key] = 1;
                }
            }
            levels[i] = n;
        }
        else {
            for (const key in o) {
                accounted_for[key] = 1;
            }
        }
    }
    for (const key in to_null_out) {
        if (!(key in update))
            update[key] = undefined;
    }
    return update;
}
function mount_component(component, target, anchor) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    // onMount happens before the initial afterUpdate
    add_render_callback(() => {
        const new_on_destroy = on_mount.map(run).filter(is_function);
        if (on_destroy) {
            on_destroy.push(...new_on_destroy);
        }
        else {
            // Edge case - component was destroyed immediately,
            // most likely as a result of a binding initialising
            run_all(new_on_destroy);
        }
        component.$$.on_mount = [];
    });
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        before_update: [],
        after_update: [],
        context: new Map(parent_component ? parent_component.$$.context : []),
        // everything else
        callbacks: blank_object(),
        dirty,
        skip_bound: false
    };
    let ready = false;
    $$.ctx = instance
        ? instance(component, options.props || {}, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if (!$$.skip_bound && $$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor);
        flush();
    }
    set_current_component(parent_component);
}
/**
 * Base class for Svelte components. Used when dev=false.
 */
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set($$props) {
        if (this.$$set && !is_empty($$props)) {
            this.$$.skip_bound = true;
            this.$$set($$props);
            this.$$.skip_bound = false;
        }
    }
}

/**
 * @param {HTMLElement} node
 * @param {{ [key: string]: string; }} properties
 */
function setProperties(node, properties) {
  Object.entries(properties).forEach(([key, value]) => {
    node.style.setProperty(`--js-${key}`, value);
  });
}

/**
 * @name CSSAction
 * @description Use Svelte variables as css variables
 * @example ```javascript
 * <div use:css={{ color: someColorVariable }}></div>
 * <style>
 * div {
 *  color: var(--js-color);
 * }
 * </style>
 * ```
 * @param {HTMLElement} node 
 * @param {{[key: string]: string}} properties 
 */
function css(node, properties) {
  setProperties(node, properties);

  return {
    update(properties) {
      setProperties(node, properties);
    }
  }
}

/**
   * @returns {import("../../types/GetCssProperties").CssProperties}
   */
function getCssProperties({ color, textColor, outlined }) {
  if (outlined) {
    return {
      background: "transparent",
      color: color,
      "border-color": color,
    }
  } else {
    return {
      background: color,
      color: textColor,
      "border-color": color
    }
  }
}

/** @type {import("../types/ThemeConfig").default} */
const ThemeConfig = window.SVELTE_THEME_CONFIG || {
  colors: {
    primary: {
      "100": "#DBEAFE",
      "200": "#BFDBFE",
      "300": "#93C5FD",
      "400": "#60A5FA",
      "500": "#3B82F6",
      "600": "#2563EB",
      "700": "#1D4ED8",
      "800": "#1E40AF",
      "900": "#1E3A8A"
    },
    secondary: {
      "100": "#D1FAE5",
      "200": "#A7F3D0",
      "300": "#6EE7B7",
      "400": "#34D399",
      "500": "#10B981",
      "600": "#059669",
      "700": "#047857",
      "800": "#065F46",
      "900": "#064E3B"
    },
  }
};

function getThemeConfig() {
  return window.SVELTE_THEME_CONFIG || ThemeConfig
}

/**
 * Helper function to get theme color
 * @param {string} color Primary, secondary or any other key in ThemeConfig
 * @param {number | string} shade Shade number
 * @returns {import("../../types/ThemeConfig").ColorConfig["500"] | undefined} Required shade
 */
function getThemeColor(color, shade) {
  const ThemeConfig = getThemeConfig();
  if (typeof shade === "number") {
    shade = `${shade}`;
  }

  return ThemeConfig.colors?.[color]?.[shade] ?? undefined
}

/* src/components/Button.svelte generated by Svelte v3.32.3 */

function add_css() {
	var style = element("style");
	style.id = "svelte-1inx6ug-style";
	style.textContent = "button.svelte-1inx6ug{color:var(--js-color);background:var(--js-background);border:1px solid var(--js-border-color);border-radius:6px;padding:0.5rem 1rem;cursor:pointer;font-size:0.9rem}button.svelte-1inx6ug:hover,button.svelte-1inx6ug:focus{filter:brightness(120%)}button.svelte-1inx6ug:active{filter:brightness(75%)}button.svelte-1inx6ug:focus{outline:1px dashed black}button.svelte-1inx6ug:disabled{background:grey;border-color:grey;color:white;cursor:not-allowed}";
	append(document.head, style);
}

function create_fragment(ctx) {
	let button;
	let css_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[5], null);
	let button_levels = [/*$$restProps*/ ctx[1]];
	let button_data = {};

	for (let i = 0; i < button_levels.length; i += 1) {
		button_data = assign(button_data, button_levels[i]);
	}

	return {
		c() {
			button = element("button");
			if (default_slot) default_slot.c();
			set_attributes(button, button_data);
			toggle_class(button, "svelte-1inx6ug", true);
		},
		m(target, anchor) {
			insert(target, button, anchor);

			if (default_slot) {
				default_slot.m(button, null);
			}

			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(css_action = css.call(null, button, /*cssProperties*/ ctx[0])),
					listen(button, "click", /*click_handler*/ ctx[7])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && dirty & /*$$scope*/ 32) {
					update_slot(default_slot, default_slot_template, ctx, /*$$scope*/ ctx[5], dirty, null, null);
				}
			}

			set_attributes(button, button_data = get_spread_update(button_levels, [dirty & /*$$restProps*/ 2 && /*$$restProps*/ ctx[1]]));
			if (css_action && is_function(css_action.update) && dirty & /*cssProperties*/ 1) css_action.update.call(null, /*cssProperties*/ ctx[0]);
			toggle_class(button, "svelte-1inx6ug", true);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let cssProperties;
	const omit_props_names = ["outlined","color","textColor"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	let { outlined = false } = $$props;
	let { color = getThemeColor("primary", 500) } = $$props;
	let { textColor = "white" } = $$props;

	function click_handler(event) {
		bubble($$self, event);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(1, $$restProps = compute_rest_props($$props, omit_props_names));
		if ("outlined" in $$new_props) $$invalidate(2, outlined = $$new_props.outlined);
		if ("color" in $$new_props) $$invalidate(3, color = $$new_props.color);
		if ("textColor" in $$new_props) $$invalidate(4, textColor = $$new_props.textColor);
		if ("$$scope" in $$new_props) $$invalidate(5, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*color, textColor, outlined*/ 28) {
			$$invalidate(0, cssProperties = getCssProperties({ color, textColor, outlined }));
		}
	};

	return [
		cssProperties,
		$$restProps,
		outlined,
		color,
		textColor,
		$$scope,
		slots,
		click_handler
	];
}

class Button extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-1inx6ug-style")) add_css();
		init(this, options, instance, create_fragment, safe_not_equal, { outlined: 2, color: 3, textColor: 4 });
	}
}

/* src/components/Avatar.svelte generated by Svelte v3.32.3 */

function add_css$1() {
	var style = element("style");
	style.id = "svelte-1hw8don-style";
	style.textContent = "img.svelte-1hw8don{border:2px solid var(--js-border-color);border-radius:9999px;min-width:10rem;width:50%;max-width:14rem}";
	append(document.head, style);
}

function create_fragment$1(ctx) {
	let img;
	let img_src_value;
	let css_action;
	let mounted;
	let dispose;

	let img_levels = [
		{ src: img_src_value = /*src*/ ctx[0] },
		{ alt: /*alt*/ ctx[1] },
		/*$$restProps*/ ctx[3]
	];

	let img_data = {};

	for (let i = 0; i < img_levels.length; i += 1) {
		img_data = assign(img_data, img_levels[i]);
	}

	return {
		c() {
			img = element("img");
			set_attributes(img, img_data);
			toggle_class(img, "svelte-1hw8don", true);
		},
		m(target, anchor) {
			insert(target, img, anchor);

			if (!mounted) {
				dispose = action_destroyer(css_action = css.call(null, img, { "border-color": /*color*/ ctx[2] }));
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			set_attributes(img, img_data = get_spread_update(img_levels, [
				dirty & /*src*/ 1 && img.src !== (img_src_value = /*src*/ ctx[0]) && { src: img_src_value },
				dirty & /*alt*/ 2 && { alt: /*alt*/ ctx[1] },
				dirty & /*$$restProps*/ 8 && /*$$restProps*/ ctx[3]
			]));

			if (css_action && is_function(css_action.update) && dirty & /*color*/ 4) css_action.update.call(null, { "border-color": /*color*/ ctx[2] });
			toggle_class(img, "svelte-1hw8don", true);
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(img);
			mounted = false;
			dispose();
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	const omit_props_names = ["src","alt","color"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { src } = $$props;
	let { alt = "Avatar Image" } = $$props;
	let { color = getThemeColor("primary", 500) } = $$props;

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(3, $$restProps = compute_rest_props($$props, omit_props_names));
		if ("src" in $$new_props) $$invalidate(0, src = $$new_props.src);
		if ("alt" in $$new_props) $$invalidate(1, alt = $$new_props.alt);
		if ("color" in $$new_props) $$invalidate(2, color = $$new_props.color);
	};

	return [src, alt, color, $$restProps];
}

class Avatar extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-1hw8don-style")) add_css$1();
		init(this, options, instance$1, create_fragment$1, safe_not_equal, { src: 0, alt: 1, color: 2 });
	}
}

export { Avatar, Button, getThemeColor };
